@@ -6,7 +6,12 @@ use Tk;
 $mw = MainWindow->new;
 $mw->title("{\@");
 
-$mw->Button(@font, '-text' => '{\@')->pack;
+$mw->Button(@font, '-text' => '{\@', '-command' => sub {
+    my $openfile = $mw->getOpenFile();
+    print "openfile=($openfile)\n";
+    my $savefile = $mw->getSaveFile();
+    print "savefile=($savefile)\n";
+})->pack;
 $mw->Label(@font, '-text' => '{\@')->pack;
 $mw->Checkbutton(@font, '-text' => '{\@')->pack;
 $mw->Radiobutton(@font, '-text' => '{\@')->pack;
